#include <stdio.h>
#include <assert.h>

float f=1.11;
double d=3.14;

char s[] = "2.22,1.234567";

int main()
{
	sscanf(s, "%f,%lf", &f, &d);
	printf("f=%f, d=%lf\n", f, d);
	assert(f == 2.22f);
	assert(d == 1.234567);
	return 0;
}
